@@ -1,10 +1,18 @@
-import requests_html, os, sys
+import requests_html, json, os, sys
+import PySimpleGUI as sg
 from bs4 import BeautifulSoup as BSoup
+from requests.adapters import HTTPAdapter
+from requests.packages.urllib3.util.retry import Retry
 
 ## function to login to bold
 def login(username, password, certificate):
     ## start a new html session
     session = requests_html.HTMLSession(verify = certificate)
+    session.headers.update({"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/98.0.4758.82 Safari/537.36"})
+    retry_strategy = Retry(total = 15, status_forcelist = [400, 401, 403, 404, 413, 429, 500, 502, 503, 504], backoff_factor = 1)
+    adapter = HTTPAdapter(max_retries = retry_strategy)
+    session.mount('https://', adapter)
+    session.mount('http://', adapter)
 
     ## data to push into the post request
     data = {
@@ -23,11 +31,11 @@ def login(username, password, certificate):
     content = soup.find(class_ = 'site-navigation nav navbar-nav')
     tags = content.find_all('a')
     if tags[5].text != 'Log out':
-        print('No login possible. Please check your userdata.')
+        print('Unable to login.\nPlease check your userdata.')
         sys.exit()
     else:
-        print('Login successfull')
-
+        print('Login successful.')
+        
     ## return the session, not neccessary for this check but
     ## useful if you want to do other things with the login
     return session
